@@ -25,7 +25,7 @@ def main():
     cov.load()
     c = total(cov)
 
-    auto_user, auto_repo = slug.autodetect()
+    auto_user, auto_repo = slug.autodetect() if not args.user or not args.repo else (None, None)
     user, repo = args.user or auto_user, args.repo or auto_repo
     if user and repo:
         svg = upload(args.url,
